    		https://documentation.tradier.com/brokerage-api/markets/get-options-chains

    			ranked

    				pricyness ratio

    					This is how expensive the options are.

    				volume ratio

    					This is the market cap ratio.

    			NASDAQ

    				https://data.nasdaq.com/search?filters=%5B%22Options%22%5D&query=options

    				https://docs.data.nasdaq.com/

    					GET https://data.nasdaq.com/api/v3/datasets/{database_code}/{dataset_code}/data.{return_format}

    					python:
    						nasdaq-data-link

    					API:

    				https://data.nasdaq.com/tools/api

    				curl https://data.nasdaq.com/api/v3/datasets/WIKI/AAPL.csv